package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Jun 17, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package sqlitex implements hubx.ClientProvider for "dbx.sqlite".
type Config struct {
DSN string `yaml:"dsn"`
MaxOpenConns int `yaml:"max_open_conns"`
MaxIdleConns int `yaml:"max_idle_conns"`
ConnMaxLifetime time.Duration `yaml:"conn_max_lifetime"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.